%{!?upstream_version: %global upstream_version %{version}%{?milestone}}
%global modulename neutron_lbaas
%global servicename neutron-lbaas
%global type LBaaS
%global min_neutron_version 1:8.0.0

Name:           openstack-%{servicename}
Version:        10.0.1
Release:        10%{?dist}
Epoch:          1
Summary:        Openstack Networking %{type} plugin

License:        ASL 2.0
URL:            http://launchpad.net/neutron/
Source0:        https://tarballs.openstack.org/%{servicename}/%{servicename}-%{upstream_version}.tar.gz
Source2:        %{servicename}v2-agent.service
Source3:        %{servicename}-dist.conf

# patches_base=10.0.1
Patch0001: 0001-Updated-from-global-requirements.patch
Patch0002: 0002-Prevent-LBaaSv2-agent-from-filling-up-logs.patch
Patch0003: 0003-Switch-to-use-stable-data_utils.patch
Patch0004: 0004-Fixes-module-not-found-error-in-NetScaler-LBaaSV2-dr.patch
Patch0005: 0005-fixed-statuses-as-it-was-using-an-undefined-variable.patch
Patch0006: 0006-fixed-health-monitor-setting-during-tempest-test.patch
Patch0007: 0007-Adds-L7-policy-and-rule-support.patch
Patch0008: 0008-Don-t-forget-to-call-the-super-s-resource_cleanup.patch
Patch0009: 0009-Move-neutron-lbaas-zuulv3-configuration-in-repo.patch
Patch0010: 0010-Disable-kvm-on-OVH-infra-instances.patch
Patch0011: 0011-Fix-tempest-scenario-tests-waiters.patch
Patch0012: 0012-Update-pool-member-operating-status-for-haproxy.patch
Patch0013: 0013-Fix-KeyError-exception-in-ChanceScheduler.schedule.patch
Patch0014: 0014-More-zuul-v3-updates.patch
Patch0015: 0015-Octavia-driver-to-honor-Octavia-API-status-codes.patch
Patch0016: 0016-Add-missing-NAME-attribute-for-SessionPersistenceV2.patch

# patches_ignore=DROP-IN-RPM

BuildArch:      noarch
BuildRequires:  openstack-macros
BuildRequires:  python2-devel
BuildRequires:  python-barbicanclient
BuildRequires:  python-neutron >= %{min_neutron_version}
BuildRequires:  python-neutron-lib
BuildRequires:  python-pbr
BuildRequires:  python-pyasn1
BuildRequires:  python-pyasn1-modules
BuildRequires:  python-setuptools
BuildRequires:  systemd-units
BuildRequires:	git
# Test deps
BuildRequires:  python-cryptography

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}
Requires:       openstack-neutron >= %{min_neutron_version}
Requires:       python-neutron-lib >= 1.1.0

# This is not a hard dependency, but it's required by the default lbaas driver
Requires:       haproxy

%description
This is a %{type} service plugin for Openstack Neutron (Networking) service.


%package -n python-%{servicename}
Summary:        Neutron %{type} Python libraries
Group:          Applications/System

Requires:       python-neutron >= %{min_neutron_version}
Requires:       python-alembic >= 0.8.4
Requires:       python-barbicanclient >= 4.0.0
Requires:       python-cryptography
Requires:       python-eventlet
Requires:       python-keystoneauth1 >= 2.18.0
Requires:       python-netaddr >= 0.7.12
Requires:       python-oslo-config >= 2:3.14.0
Requires:       python-oslo-db >= 4.15.0
Requires:       python-oslo-log >= 3.11.0
Requires:       python-oslo-messaging >= 5.14.0
Requires:       python-oslo-serialization >= 1.10.0
Requires:       python-oslo-service >= 1.10.0
Requires:       python-oslo-reports >= 0.6.0
Requires:       python-oslo-utils >= 3.18.0
Requires:       python-pbr
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Requires:       python-requests
Requires:       python-six >= 1.9.0
Requires:       python-sqlalchemy >= 1.0.10
Requires:       python-stevedore >= 1.17.1
Requires:       pyOpenSSL


%description -n python-%{servicename}
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains the Neutron %{type} Python library.


%package -n python-%{servicename}-tests
Summary:        Neutron %{type} tests
Group:          Applications/System

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}


%description -n python-%{servicename}-tests
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains Neutron %{type} test files.


%prep
%autosetup -n %{servicename}-%{upstream_version} -S git

# Let's handle dependencies ourselves
rm -f requirements.txt

# Kill egg-info in order to generate new SOURCES.txt
rm -rf neutron_lbaas.egg-info

%build
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build

# Generate configuration files
PYTHONPATH=. tools/generate_config_file_samples.sh
find etc -name *.sample | while read filename
do
    filedir=$(dirname $filename)
    file=$(basename $filename .sample)
    mv ${filename} ${filedir}/${file}
done

# Loop through values in neutron-lbaas-dist.conf and make sure that the values
# are substituted into the lbaas_agent.ini as comments.
while read name eq value; do
  if [ -n "$name" -a -n "$value" ]; then
    sed -ri "0,/^(#)? *$name *=/{s!\(^(#)? *$name *=\).*!\1 $value!}" etc/lbaas_agent.ini
  fi
done < %{SOURCE3}


%install
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Move rootwrap files to proper location
install -d -m 755 %{buildroot}%{_datarootdir}/neutron/rootwrap
mv %{buildroot}/usr/etc/neutron/rootwrap.d/*.filters %{buildroot}%{_datarootdir}/neutron/rootwrap

# Move config files to proper location
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron

# The generated config files are not moved automatically by setup.py
mv etc/*.ini etc/*.conf %{buildroot}%{_sysconfdir}/neutron

# Install systemd units
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{servicename}v2-agent.service

# Install dist conf
install -p -D -m 640 %{SOURCE3} %{buildroot}%{_datadir}/neutron/%{servicename}-dist.conf

# Create configuration directories that can be populated by users with custom *.conf files
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent

# Make sure neutron-server loads new configuration file
mkdir -p %{buildroot}/%{_datadir}/neutron/server
ln -s %{_sysconfdir}/neutron/%{modulename}.conf %{buildroot}%{_datadir}/neutron/server/%{modulename}.conf

%py2_entrypoint %{modulename} %{servicename}

%post
%systemd_post %{servicename}v2-agent.service


%preun
%systemd_preun %{servicename}v2-agent.service


%postun
%systemd_postun_with_restart %{servicename}v2-agent.service


%files
%license LICENSE
%doc AUTHORS CONTRIBUTING.rst README.rst
%{_bindir}/%{servicename}v2-agent
%{_unitdir}/%{servicename}v2-agent.service
%{_datarootdir}/neutron/rootwrap/lbaas-haproxy.filters
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/lbaas_agent.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/neutron_lbaas.conf
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/services_lbaas.conf
%dir %{_sysconfdir}/neutron/conf.d
%dir %{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent
%attr(-, root, neutron) %{_datadir}/neutron/%{servicename}-dist.conf
%{_datadir}/neutron/server/%{modulename}.conf


%files -n python-%{servicename}
%{python2_sitelib}/%{modulename}
%{python2_sitelib}/%{modulename}-%{version}-py%{python2_version}.egg-info
%exclude %{python2_sitelib}/%{modulename}/tests


%files -n python-%{servicename}-tests
%{python2_sitelib}/%{modulename}/tests
%{python2_sitelib}/%{modulename}_tests.egg-info

%changelog
* Mon Dec 25 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.1-10
- Add missing NAME attribute for SessionPersistenceV2 (rhbz#1528318)

* Thu Dec 21 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.1-9
- Octavia driver to honor Octavia API status codes
- More zuul v3 updates
- Fix KeyError exception in ChanceScheduler.schedule

* Mon Dec 11 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.1-8
- Update pool member operating status for haproxy (rhbz#1522711)

* Tue Nov 14 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.1-7
- Fix tempest scenario tests waiters (rhbz#1433683)

* Wed Nov 08 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.1-6
- Disable kvm on OVH infra instances
- Move neutron-lbaas zuulv3 configuration in repo
- Don't forget to call the super's resource_cleanup

* Mon Oct 23 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.1-5
- Adds L7 policy and rule support (rhbz#1505322)

* Thu Sep 21 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.1-4
- fixed health monitor setting during tempest test,
- fixed statuses, as it was using an undefined variable

* Tue Sep 12 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.1-3
- Fixes module not found error in NetScaler LBaaSV2 driver (rhbz#1461184)

* Mon Aug 14 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.1-2
- Switch to use stable data_utils
- Prevent LBaaSv2 agent from filling up logs.

* Mon Jun 26 2017 Jason Joyce <jjoyce@redhat.com> 1:10.0.1-1
- Update to 10.0.1

* Wed Apr 19 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.0-8
- Tests helper function _send_requests should catch socket.error

* Mon Apr 17 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.0-7
- Create header with authtoken for requests without args

* Fri Apr 07 2017 Jakub Libosvar <libosvar@redhat.com> 1:10.0.0-6
- api test: Check the correct extension (rhbz#1439772)

* Mon Apr 03 2017 Jon Schlueter <jschluet@redhat.com> 1:10.0.0-5
- Explicitly list neutron api extensions for tests

* Sun Apr 02 2017 Nir Magnezi <nmagnezi@redhat.com> 1:10.0.0-4
- Don't use Tempest internal methods (rhbz#1435974)
- Updated from global requirements

* Thu Mar 23 2017 Jon Schlueter <jschluet@redhat.com> 1:10.0.0-3
- tempest: Switch to local copy of tempset/scenario/manager.py
- gate_hook: Stop writing local.conf directly

* Fri Mar 17 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.0-2
- Update tox_install.sh for stable/ocata
- Update UPPER_CONSTRAINTS_FILE for stable/ocata

* Wed Feb 22 2017 Alfredo Moralejo <amoralej@redhat.com> 1:10.0.0-1
- Update to 10.0.0

* Thu Feb 16 2017 Alfredo Moralejo <amoralej@redhat.com> 1:10.0.0-0.1.0rc1
- Update to 10.0.0.0rc1

